.. _install:
Installation
============


.. _installing:
-------------------------
Installing Recipe_Caching
-------------------------

Distribute & Pip
----------------

The recommended way to install Recipe is with `pip
<http://www.pip-installer.org/>`_::

    $ pip install recipe_caching


-------------------
Download the Source
-------------------

You can also install recipe from source. The latest release (|version|) is
available from GitHub.

* tarball_
* zipball_

.. _

Once you have a copy of the source, you can embed it in your Python package, or
install it into your site-packages easily.

::

    $ python setup.py install


.. _tarball: http://github.com/juiceinc/recipe_caching/tarball/master
.. _zipball: http://github.com/juiceinc/recipe_caching/zipball/master



.. _updates:
Staying Updated
---------------

The latest version of Recipe will always be available here:

* PyPi: http://pypi.python.org/pypi/recipe_caching/
* GitHub: http://github.com/juiceinc/recipe_caching/

When a new version is available, upgrading is simple::

    $ pip install recipe_caching --upgrade


Now, go get a :ref:`Quick Start <quickstart>`.
